

<script type="text/javascript">
    var initData{{ widget.attrs.id }} = {
        style: '.txt-red{color: red}',
        plugins: ['gjs-preset-newsletter'],
        pluginsOpts: {
            'gjs-preset-newsletter': {
                modalTitleImport: 'Import template',
            }
        }
    }

</script>